@@ -2,25 +2,24 @@
 #                                                           #
 #	PLOT.WLE.CP function                                #
 #	E-mail: claudio@stat.unipd.it                       #
-#	Date: December, 19, 2000                            #
-#	Version: 0.3                                        #
+#	Date: August, 2, 2001                               #
+#	Version: 0.4                                        #
 #                                                           #
-#	Copyright (C) 2000 Claudio Agostinelli              #
+#	Copyright (C) 2001 Claudio Agostinelli              #
 #                                                           #
 #############################################################
 
-plot.wle.cp <- function(object, base.line=0, num.max=20, plot.it=TRUE, log.scale=FALSE, xlab="Number of Predictors", ylab=NULL)
-{
+plot.wle.cp <- function(x, base.line=0, num.max=20, plot.it=TRUE, log.scale=FALSE, xlab="Number of Predictors", ylab=NULL, verbose=FALSE, ...) {
 
-z <- .Alias(object)
+z <- .Alias(x)
 if (is.null(z$terms)) {
     stop("invalid \'wle.cp\' object")
 }
 
-wcp <- object$wcp
+wcp <- x$wcp
 
 if (num.max<1) {
-cat("plot.wle.cp: num.max can not less than 1, num.max=1 \n")
+    if (verbose) cat("plot.wle.cp: num.max can not less than 1, num.max=1 \n")
 num.max <- 1
 }
 
@@ -30,16 +29,15 @@ if(is.null(nrow(wcp)) | nrow(wcp)==1) {
     num.model <- nrow(wcp) 
 }
 
-if(num.model<num.max)
-{
-cat("plot.wle.cp: The number of models is less than num.max \n")
-num.max <- num.model
+if (num.model<num.max) {
+    if (verbose) cat("plot.wle.cp: The number of models is less than num.max \n")
+    num.max <- num.model
 }
 
 if(is.null(ncol(wcp))) {
-stop("No models to plot")
+   stop("No models to plot")
 } else {
-nvar <- ncol(wcp)-1
+   nvar <- ncol(wcp)-1
 }
 
 good.model <- (apply(wcp[,1:nvar],1,sum)+base.line>=wcp[,nvar+1])
