@@ -3,14 +3,14 @@
 #	WLE.LM function                                     #
 #	Author: Claudio Agostinelli                         #
 #	E-mail: claudio@stat.unipd.it                       #
-#	Date: December, 19, 2000                            #
-#	Version: 0.3                                        #
+#	Date: August, 2, 2001                               #
+#	Version: 0.4                                        #
 #                                                           #
-#	Copyright (C) 2000 Claudio Agostinelli              #
+#	Copyright (C) 2001 Claudio Agostinelli              #
 #                                                           #
 #############################################################
 
-wle.lm <- function(formula, data=list(), model=TRUE, x=FALSE, y=FALSE, boot=30, group, num.sol=1, raf="HD", smooth=0.031, tol=10^(-6), equal=10^(-3), max.iter=500, contrasts=NULL)
+wle.lm <- function(formula, data=list(), model=TRUE, x=FALSE, y=FALSE, boot=30, group, num.sol=1, raf="HD", smooth=0.031, tol=10^(-6), equal=10^(-3), max.iter=500, contrasts=NULL, verbose=FALSE)
 {
 
 raf <- switch(raf,
@@ -34,6 +34,7 @@ group <- 0
     mf$tol <- mf$equal <- mf$num.sol <- NULL
     mf$max.iter <- mf$raf <- mf$contrasts <- NULL
     mf$model <- mf$x <- mf$y <- NULL
+    mf$verbose <- NULL
     mf$drop.unused.levels <- TRUE
     mf[[1]] <- as.name("model.frame")
     mf <- eval(mf, sys.frame(sys.parent()))
@@ -55,42 +56,42 @@ if (is.null(size <- nrow(xdata)) | is.null(nvar <- ncol(xdata))) stop("'x' must
 if (length(ydata)!=size) stop("'y' and 'x' are not compatible")
 
 if (size<nvar) {
-stop("Number of observations must be at least equal to the number of predictors (including intercept)")
+    stop("Number of observations must be at least equal to the number of predictors (including intercept)")
 }
 
 if (group<nvar) {
-group <- max(round(size/4),nvar)
-cat("wle.lm: dimension of the subsample set to default value: ", group,"\n")
+    group <- max(round(size/4),nvar)
+    if (verbose) cat("wle.lm: dimension of the subsample set to default value: ", group,"\n")
 }
 
 maxboot <- sum(log(1:size))-(sum(log(1:group))+sum(log(1:(size-group))))
 
 if (boot<1 | log(boot) > maxboot) {
-stop("Bootstrap replication not in the range")
+    stop("Bootstrap replication not in the range")
 }
 
 if (!(num.sol>=1)) {
-cat("wle.lm: number of solution to report set to 1 \n")
-num.sol <- 1
+    if (verbose) cat("wle.lm: number of solution to report set to 1 \n")
+    num.sol <- 1
 }
 
 if (max.iter<1) {
-cat("wle.lm: max number of iteration set to 500 \n")
-max.iter <- 500
+    if (verbose) cat("wle.lm: max number of iteration set to 500 \n")
+    max.iter <- 500
 }
 
 if (smooth<10^(-5)) {
-cat("wle.lm: the smooth parameter seems too small \n")
+    if (verbose) cat("wle.lm: the smooth parameter seems too small \n")
 }
 
-if (tol<0) {
-cat("wle.lm: the accuracy can not be negative, using default value \n")
-tol <- 10^(-6)
+if (tol<=0) {
+    if (verbose) cat("wle.lm: the accuracy must be positive, using default value: 10^(-6) \n")
+    tol <- 10^(-6)
 }
 
-if (equal<0) {
-cat("wle.lm: the equal parameter can not be negative, using default value \n")
-equal <- 10^(-3)
+if (equal<=tol) {
+    if (verbose) cat("wle.lm: the equal parameter must be greater than tol, using default value: tol+10^(-3) \n")
+    equal <- tol+10^(-3)
 }
 
   z <- .Fortran("wleregfix",
@@ -113,54 +114,77 @@ equal <- 10^(-3)
 	resid=mat.or.vec(num.sol,size),
 	totweight=double(num.sol),
 	weight=mat.or.vec(num.sol,size),
+        density=mat.or.vec(num.sol,size),
+        model=mat.or.vec(num.sol,size),
+        delta=mat.or.vec(num.sol,size),
 	same=integer(num.sol),
 	nsol=integer(1),
 	nconv=integer(1),
 	PACKAGE = "wle")
 
 if (z$nsol>0) {
-z$var <- z$var[1:z$nsol]
-z$totweight <- z$totweight[1:z$nsol]
-z$same <- z$same[1:z$nsol]
+    z$var <- z$var[1:z$nsol]
+    z$totweight <- z$totweight[1:z$nsol]
+    z$same <- z$same[1:z$nsol]
 
-if (num.sol==1)
-{
-z$param <- c(z$param)
-z$resid <- c(z$resid)
-z$weight <- c(z$weight)
-}
-else
-{
-z$param <- z$param[1:z$nsol,]
-z$resid <- z$resid[1:z$nsol,]
-z$weight <- z$weight[1:z$nsol,]
+    if (num.sol==1) {
+        z$param <- c(z$param)
+        z$resid <- c(z$resid)
+        z$weight <- c(z$weight)
+        z$density <- c(z$density)
+        z$model <- c(z$model)
+        z$delta <- c(z$delta)        
+    } else {
+        z$param <- z$param[1:z$nsol,]
+        z$resid <- z$resid[1:z$nsol,]
+        z$weight <- z$weight[1:z$nsol,]
+        z$density <- z$density[1:z$nsol,]
+        z$model <- z$model[1:z$nsol,]
+        z$delta <- z$delta[1:z$nsol,]
+   }
+
+    y.fit <- t(xdata%*%matrix(z$param,ncol=z$nsol,byrow=TRUE))
+
+    if (z$nsol==1) {
+        devparam <- sqrt(z$var*diag(solve(t(xdata)%*%diag(z$weight)%*%xdata,tol=1e-100)))
+        y.fit <- as.vector(y.fit)
+    } else {
+        devparam <- sqrt(z$var[1]*diag(solve(t(xdata)%*%diag(z$weight[1,])%*%xdata,tol=1e-100)))
+        for (i in 2:z$nsol) {
+             devparam <- rbind(devparam,sqrt(z$var[i]*diag(solve(t(xdata)%*%diag(z$weight[i,])%*%xdata,tol=1e-100))))
+        }
+    }
+
+    result$coefficients <- z$param
+    result$standard.error <- devparam
+    result$scale <- sqrt(z$var)
+    result$residuals <- z$resid
+    result$fitted.values <- y.fit
+    result$weights <- z$weight
+    result$f.density <- z$density
+    result$m.density <- z$model
+    result$delta <- z$delta
+    result$tot.weights <- z$totweight
+    result$tot.sol <- z$nsol
+    result$not.conv <- z$nconv
+    result$freq <- z$same
+} else {
+    if (verbose) cat("wle.lm: No solutions are fuond, checks the parameters\n")
+    result$coefficients <- rep(NA,nvar)
+    result$standard.error <- rep(NA,nvar)
+    result$scale <- NA
+    result$residuals <- rep(NA,size)
+    result$fitted.values <- rep(NA,size)
+    result$weights <- rep(NA,size)
+    result$f.density <- rep(NA,size)
+    result$m.density <- rep(NA,size)
+    result$delta <- rep(NA,size)
+    result$tot.weights <- NA
+    result$tot.sol <- 0
+    result$not.conv <- boot
+    result$freq <- NA
 }
 
-y.fit <- t(xdata%*%matrix(z$param,ncol=z$nsol,byrow=TRUE))
-
-if(z$nsol==1)
-{
-devparam <- sqrt(z$var*diag(solve(t(xdata)%*%diag(z$weight)%*%xdata,tol=1e-100)))
-y.fit <- as.vector(y.fit)
-}
-else
-{
-devparam <- sqrt(z$var[1]*diag(solve(t(xdata)%*%diag(z$weight[1,])%*%xdata,tol=1e-100)))
-for(i in 2:z$nsol){
-devparam <- rbind(devparam,sqrt(z$var[i]*diag(solve(t(xdata)%*%diag(z$weight[i,])%*%xdata,tol=1e-100))))
-}
-}
-
-result$coefficients <- z$param
-result$standard.error <- devparam
-result$scale <- sqrt(z$var)
-result$residuals <- z$resid
-result$fitted.values <- y.fit
-result$weights <- z$weight
-result$tot.weights <- z$totweight
-result$tot.sol <- z$nsol
-result$not.conv <- z$nconv
-result$freq <- z$same
 result$call <- cl
 result$info <- z$info
 result$contrasts <- attr(xdata, "contrasts")
@@ -181,14 +205,9 @@ names(result$coefficients) <- dn
 } else {
 dimnames(result$coefficients) <- list(NULL,dn)
 }
-
 class(result) <- "wle.lm"
 
 return(result)
-} else {
-stop("No solutions are fuond, checks the parameters")
-}
-
 }
 
 print.wle.lm <- function(x, digits = max(3, getOption("digits") - 3), ...)
@@ -349,7 +368,7 @@ print.summary.wle.lm.root <- function (x, digits = max(3, getOption("digits") -
 fitted.wle.lm <- function(object, ...) object$fitted.values
 coef.wle.lm <- function(object, ...) object$coefficients
 weights.wle.lm <- .Alias(weights.default)
-formula.wle.lm <- function(object, ...) formula(object$terms)
+formula.wle.lm <- function(x, ...) formula(x$terms)
 
 model.frame.wle.lm <-
     function(formula, data, na.action, ...) {
