@@ -3,14 +3,14 @@
 #	WLE.STEPWISE function                               #
 #	Author: Claudio Agostinelli                         #
 #	E-mail: claudio@stat.unipd.it                       #
-#	Date: December, 19, 2000                            #
-#	Version: 0.3                                        #
+#	Date: August, 3, 2001                               #
+#	Version: 0.4                                        #
 #                                                           #
-#	Copyright (C) 2000 Claudio Agostinelli              #
+#	Copyright (C) 2001 Claudio Agostinelli              #
 #                                                           #
 #############################################################
 
-wle.stepwise <- function(formula, data=list(), model=TRUE, x=FALSE, y=FALSE, boot=30, group, num.sol=1, raf="HD", smooth=0.031, tol=10^(-6), equal=10^(-3), max.iter=500, min.weight=0.5, type="Forward", f.in=4.0, f.out=4.0, method="WLE", contrasts=NULL)
+wle.stepwise <- function(formula, data=list(), model=TRUE, x=FALSE, y=FALSE, boot=30, group, num.sol=1, raf="HD", smooth=0.031, tol=10^(-6), equal=10^(-3), max.iter=500, min.weight=0.5, type="Forward", f.in=4.0, f.out=4.0, method="WLE", contrasts=NULL, verbose=FALSE)
 {
 
 raf <- switch(raf,
@@ -51,6 +51,7 @@ group <- 0
     mf$min.weight <- NULL
     mf$type <- mf$f.in <- mf$f.out <- NULL
     mf$model <- mf$x <- mf$y <- mf$method <- NULL
+    mf$verbose <- NULL
     mf$drop.unused.levels <- TRUE
     mf[[1]] <- as.name("model.frame")
     mf <- eval(mf, sys.frame(sys.parent()))
@@ -72,51 +73,51 @@ if (is.null(size <- nrow(xdata)) | is.null(nvar <- ncol(xdata))) stop("'x' must
 if (length(ydata)!=size) stop("'y' and 'x' are not compatible")
 
 if (size<nvar) {
-stop("Number of observations must be at least equal to the number of predictors (including intercept)")
+    stop("Number of observations must be at least equal to the number of predictors (including intercept)")
 }
 
 if (f.in<0 | f.out<0) {
-stop("f.in and f.out can not be negative")
+    stop("f.in and f.out can not be negative")
 }
 
 if (group<1) {
-group <- max(round(size/4),nvar)
-cat("wle.stepwise: dimension of the subsample set to default value: ",group,"\n")
+    group <- max(round(size/4),nvar)
+    if (verbose) cat("wle.stepwise: dimension of the subsample set to default value: ",group,"\n")
 }
 
 maxboot <- sum(log(1:size))-(sum(log(1:group))+sum(log(1:(size-group))))
 
 if (boot<1 | log(boot) > maxboot) {
-stop("Bootstrap replication not in the range")
+    stop("Bootstrap replication not in the range")
 }
 
 if (!(num.sol>=1)) {
-cat("wle.stepwise: number of solution to report set to 1 \n")
-num.sol <- 1
+    if (verbose) cat("wle.stepwise: number of solution to report set to 1 \n")
+    num.sol <- 1
 }
 
 if (max.iter<1) {
-cat("wle.stepwise: max number of iteration set to 500 \n")
-max.iter <- 500
+    if (verbose) cat("wle.stepwise: max number of iteration set to 500 \n")
+    max.iter <- 500
 }
 
 if (smooth<10^(-5)) {
-cat("wle.stepwise: the smooth parameter seems too small \n")
+    if (verbose) cat("wle.stepwise: the smooth parameter seems too small \n")
 }
 
-if (tol<0) {
-cat("wle.stepwise: the accuracy can not be negative, using default value \n")
-tol <- 10^(-6)
+if (tol<=0) {
+    if (verbose) cat("wle.stepwise: the accuracy must be positive, using default value: 10^(-6)\n")
+    tol <- 10^(-6)
 }
 
-if (equal<0) {
-cat("wle.stepwise: the equal parameter can not be negative, using default value \n")
-equal <- 10^(-3)
+if (equal<=tol) {
+    if (verbose) cat("wle.stepwise: the equal parameter must be greater than tol, using default value: tol+10^(-3)\n")
+    equal <- tol+10^(-3)
 }
 
 if (min.weight<0) {
-cat("wle.stepwise: the minimum sum of the weights can not be negative, using default value \n")
-min.weight <- 0.5
+    if (verbose) cat("wle.stepwise: the minimum sum of the weights can not be negative, using default value \n")
+    min.weight <- 0.5
 }
 
 nrep <- 2^nvar-1
@@ -198,7 +199,7 @@ return(result)
 
 }
 
-summary.wle.stepwise <- function (object, num.max=20, ...) {
+summary.wle.stepwise <- function (object, num.max=20, verbose=FALSE, ...) {
 
 z <- .Alias(object)
 if (is.null(z$terms)) {
@@ -206,8 +207,8 @@ if (is.null(z$terms)) {
 }
 
 if (num.max<1) {
-cat("summary.wle.stepwise: num.max can not less than 1, num.max=1 \n")
-num.max <- 1
+    if (verbose) cat("summary.wle.stepwise: num.max can not less than 1, num.max=1 \n")
+    num.max <- 1
 }
 
 ans <- list()
